@@ -1,9 +1,9 @@
-# $Id: URI.pm,v 1.2 2002/09/03 22:37:23 comdog Exp $
+# $Id: URI.pm,v 1.3 2004/11/22 00:22:41 comdog Exp $
 package Test::URI;
 use strict;
 
 use base qw(Exporter);
-use vars qw(@EXPORT);
+use vars qw(@EXPORT $VERSION);
 
 use URI;
 use Exporter;
@@ -11,7 +11,10 @@ use Test::Builder;
 
 my $Test = Test::Builder->new();
 
-@EXPORT = qw(uri_scheme_ok uri_host_ok uri_port_ok);
+@EXPORT = qw(uri_scheme_ok uri_host_ok uri_port_ok uri_fragment_ok
+	uri_path_ok);
+
+$VERSION = sprintf "%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/;
 
 =head1 NAME
 
@@ -19,10 +22,16 @@ Test::URI - Check Uniform Resource Identifiers
 
 =head1 SYNOPSIS
 
-	use Test::More tests => 1;
+	use Test::More tests => 5;
 	use Test::URI;
 	
-	uri_scheme_ok( $uri, 'gopher' );
+	# http://www.example.com:8080/index.html#name
+	
+	uri_scheme_ok( $uri, 'http' );
+	uri_host_ok( $uri, 'www.example.com' );
+	uri_port_ok( $uri, '8080' );
+	uri_path_ok( $uri, '/index.html' );
+	uri_fragment_ok( $uri, 'name' );
 	
 =head1 DESCRIPTION
 
@@ -76,41 +85,15 @@ Ok is the STRING is a valid URI, in any format that
 URI accepts, and the URI uses the same HOST.  HOST
 is not case sensitive.
 
+Not Ok is the URI scheme does not have a host portion.
+
 STRING can be an URI object.
 
 =cut
 
 sub uri_host_ok($$)
 	{	
-	my $string = shift;
-	my $host   = lc shift;
-	
-	my $uri    = ref $string ? $string : URI->new( $string );
-	
-	unless( UNIVERSAL::isa( $uri, 'URI' ) )
-		{
-		$Test->ok(0);
-		$Test->diag("URI [$string] does not appear to be valid");
-		}
-	elsif( not $uri->can('host') )
-		{
-		$Test->ok(0);
-		my $scheme = $uri->scheme;
-		$Test->diag("$scheme schemes do not have a host");
-		}		
-	elsif( $uri->host ne $host )
-		{
-		$Test->ok(0);
-		$Test->diag("URI [$string] does not have the right host\n",
-			"\tExpected [$host]\n",
-			"\tGot [" . $uri->host . "]\n",
-			);
-		}
-	else
-		{
-		$Test->ok(1);
-		}
-		
+	_methodx_ok( $_[0], $_[1], 'host' );
 	}
 
 =item uri_port_ok( STRING|URI, PORT )
@@ -118,6 +101,8 @@ sub uri_host_ok($$)
 Ok is the STRING is a valid URI, in any format that
 URI accepts, and the URI uses the same PORT.
 
+Not Ok is the URI scheme does not have a port portion.
+
 STRING can be an URI object.
 
 =cut
@@ -126,8 +111,57 @@ my %Portless = map { $_, $_ } qw(mailto file);
 
 sub uri_port_ok($$)
 	{	
-	my $string = shift;
-	my $port   = lc shift;
+	_methodx_ok( $_[0], $_[1], 'port' );		
+	}
+
+=item uri_canonical_ok
+
+UNIMPLEMENTED.  I'm not sure why I thought this should be a test.
+If anyone else knows, I'll implement it.
+
+=cut
+
+sub uri_canonical_ok($$)
+	{
+	}
+	
+=item uri_path_ok( STRING|URI, PATH )
+
+Ok is the STRING is a valid URI, in any format that
+URI accepts, and the URI has the path PATH. Remember
+that paths start with a /, even if it doesn't look
+like there is anything after the host parts.
+
+STRING can be an URI object.
+
+=cut
+
+sub uri_path_ok($$)
+	{
+	_methodx_ok( $_[0], $_[1], 'path' );
+	}
+	
+=item uri_fragment_ok( STRING|URI, FRAGMENT )
+
+
+Ok is the STRING is a valid URI, in any format that
+URI accepts, and the URI has the fragment FRAGMENT.
+
+STRING can be an URI object.
+
+=cut
+
+sub uri_fragment_ok($$)
+	{
+	_methodx_ok( $_[0], $_[1], 'fragment' );
+	}
+	
+
+sub _methodx_ok($$$)
+	{
+	my $string   = shift;
+	my $expected = shift;
+	my $methodx  = lc shift;
 	
 	my $uri    = ref $string ? $string : URI->new( $string );
 	
@@ -136,41 +170,53 @@ sub uri_port_ok($$)
 		$Test->ok(0);
 		$Test->diag("URI [$string] does not appear to be valid");
 		}
-	elsif( not $uri->can('port') )
+	elsif( not $uri->can( $methodx ) )
 		{
 		$Test->ok(0);
 		my $scheme = $uri->scheme;
-		$Test->diag("$scheme schemes do not have a port");
+		$Test->diag("$scheme schemes do not have a $methodx");
 		}		
-	elsif( $uri->port ne $port )
+	elsif( $uri->$methodx ne $expected )
 		{
 		$Test->ok(0);
-		$Test->diag("URI [$string] does not have the right port\n",
-			"\tExpected [$port]\n",
-			"\tGot [" . $uri->port . "]\n",
+		$Test->diag("URI [$string] does not have the right fragment\n",
+			"\tExpected [$expected]\n",
+			"\tGot [" . $uri->$methodx . "]\n",
 			);
 		}
 	else
 		{
 		$Test->ok(1);
 		}
-		
 	}
+
+
+sub _same_thing_exactly  { $_[0] eq $_[1] }
+sub _same_thing_caseless { _same_think_exactly( map { lc } @_ ) }
 	
 =back
 
 =head1 TO DO
 
-* add methods: uri_canonical_ok, uri_query_string_ok, uri_path_ok,
-	uri_fragment_ok, uri_same_ok
+* add methods: uri_canonical_ok, uri_query_string_ok
 	
+=head1 SOURCE AVAILABILITY
+
+This source is part of a SourceForge project which always has the
+latest sources in CVS, as well as all of the previous releases.
+
+	http://sourceforge.net/projects/brian-d-foy/
+
+If, for some reason, I disappear from the world, one of the other
+members of the project can shepherd this module appropriately.
+
 =head1 AUTHOR
 
-brian d foy, E<lt>brian d foyE<gt>
+brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright 2002 brian d foy, All rights reserved.
+Copyright 2004 brian d foy, All rights reserved.
 
 You can use this module under the same terms as
 Perl itself.
